@@ -128,7 +128,7 @@ StatWbHbar <-
                                             ypos.mult,
                                             ypos.fixed) {
                      if (length(w.band) == 0) {
-                       w.band <- waveband(data$x)
+                       w.band <- waveband(data[["x"]] )
                      }
                      if (is.any_spct(w.band) ||
                          (is.numeric(w.band) && length(na.omit(w.band)) >= 2)) {
@@ -138,7 +138,7 @@ StatWbHbar <-
                        w.band <- list(w.band)
                      }
                      stopifnot(is.function(integral.fun))
-                     w.band <- trim_wl(w.band, data$x)
+                     w.band <- trim_wl(w.band, data[["x"]] )
                      integ.df <- data.frame()
                      for (wb in w.band) {
                        if (is.numeric(wb)) { # user supplied a list of numeric vectors
@@ -146,34 +146,34 @@ StatWbHbar <-
                        }
 
                        range <- range(wb)
-                       mydata <- trim_tails(data$x, data$y, use.hinges = TRUE,
+                       mydata <- trim_tails(data[["x"]], data[["y"]], use.hinges = TRUE,
                                             low.limit = range[1],
                                             high.limit = range[2])
-                       yint.tmp <- integral.fun(mydata$x, mydata$y)
+                       yint.tmp <- integral.fun(mydata[["x"]] , mydata[["y"]] )
                        ymean.tmp <- yint.tmp / wl_expanse(wb)
                        integ.df <- rbind(integ.df,
-                                         data.frame(x = midpoint(mydata$x),
-                                                    xmin = min(wb),
-                                                    xmax = max(wb),
-                                                    ymin = min(data$y),
-                                                    ymax = max(data$y),
-                                                    yint = yint.tmp,
-                                                    ymean = ymean.tmp,
+                                         data.frame(x = midpoint(mydata[["x"]] ),
+                                                    wb.xmin = min(wb),
+                                                    wb.xmax = max(wb),
+                                                    wb.ymin = min(data[["y"]]),
+                                                    wb.ymax = max(data[["y"]]),
+                                                    wb.yint = yint.tmp,
+                                                    wb.ymean = ymean.tmp,
                                                     wb.color = color_of(wb),
-                                                    wb.name = labels(wb)$label)
+                                                    wb.name = labels(wb)[["label"]])
                                          )
                      }
                      if (is.null(ypos.fixed)) {
-                       integ.df$y <- with(integ.df, ymin + (ymean - ymin))
+                       integ.df[["y"]] <- with(integ.df, wb.ymin + (wb.ymean - wb.ymin))
                      } else {
-                       integ.df$y <- ypos.fixed
+                       integ.df[["y"]] <- ypos.fixed
                      }
                      integ.df
                    },
-                   default_aes = ggplot2::aes(xmin = ..xmin..,
-                                              xmax = ..xmax..,
-                                              yintercept = ..ymean..,
-                                              height = (..ymax.. - ..ymin..) * 2e-2,
+                   default_aes = ggplot2::aes(xmin = ..wb.xmin..,
+                                              xmax = ..wb.xmax..,
+                                              yintercept = ..wb.ymean..,
+                                              height = (..wb.ymax.. - ..wb.ymin..) * 2e-2,
                                               color = ..wb.color..),
                    required_aes = c("x", "y")
   )
