@@ -48,13 +48,13 @@
 #'   \item{y.label}{yeff multiplied by \code{label.mult} and formatted
 #'   according to \code{label.fmt}}
 #'   \item{x}{w.band-midpoint}
-#'   \item{xmin}{w.band minimum}
-#'   \item{xmax}{w.band maximum}
-#'   \item{ymin}{data$y minimum}
-#'   \item{ymax}{data$y maximum}
-#'   \item{yeff}{weighted irradiance if \code{w.band} describes a BSWF}
-#'   \item{yint}{not weighted irradiance for the range of \code{w.band}}
-#'   \item{xmean}{yint divided by wl_expanse(w.band)}
+#'   \item{wb.xmin}{w.band minimum}
+#'   \item{wb.xmax}{w.band maximum}
+#'   \item{wb.ymin}{data$y minimum}
+#'   \item{wb.ymax}{data$y maximum}
+#'   \item{wb.yeff}{weighted irradiance if \code{w.band} describes a BSWF}
+#'   \item{wb.yint}{not weighted irradiance for the range of \code{w.band}}
+#'   \item{wb.xmean}{yint divided by wl_expanse(w.band)}
 #'   \item{y}{ypos.fixed or top of data, adjusted by \code{ypos.mult}}
 #'   \item{wb.color}{color of the w.band}
 #'   \item{wb.name}{label of w.band}
@@ -66,11 +66,11 @@
 #' \describe{
 #'   \item{label}{..y.label..}
 #'   \item{x}{..x..}
-#'   \item{xmin}{..xmin..}
-#'   \item{xmax}{..xmax..}
+#'   \item{xmin}{..wb.xmin..}
+#'   \item{xmax}{..wb.xmax..}
 #'   \item{ymin}{0}
-#'   \item{ymax}{..ymean..}
-#'   \item{yintercept}{..ymean..}
+#'   \item{ymax}{..wb.ymean..}
+#'   \item{yintercept}{..wb.ymean..}
 #'   \item{fill}{..wb.color..}
 #' }
 #'
@@ -213,7 +213,7 @@ StatWbSIrrad <-
                                             xpos.fixed,
                                             ypos.fixed) {
                      if (length(w.band) == 0) {
-                       w.band <- waveband(data$x)
+                       w.band <- waveband(data[["x"]])
                      }
                      if (is.any_spct(w.band) ||
                          (is.numeric(w.band) && length(na.omit(w.band)) >= 2)) {
@@ -222,12 +222,12 @@ StatWbSIrrad <-
                      if (!is.list(w.band) || is.waveband(w.band)) {
                        w.band <- list(w.band)
                      }
-                     w.band <- trim_wl(w.band, data$x)
+                     w.band <- trim_wl(w.band, data[["x"]])
                      if (unit.in == "energy") {
-                       tmp.spct <- source_spct(w.length = data$x, s.e.irrad = data$y,
+                       tmp.spct <- source_spct(w.length = data[["x"]], s.e.irrad = data[["y"]],
                                                time.unit = time.unit)
                      } else if (unit.in %in% c("photon", "quantum")) {
-                       tmp.spct <- source_spct(w.length = data$x, s.q.irrad = data$y,
+                       tmp.spct <- source_spct(w.length = data[["x"]], s.q.irrad = data[["y"]],
                                                time.unit = time.unit)
                      } else {
                        stop("Bad 'unit.in' argument.")
@@ -248,36 +248,36 @@ StatWbSIrrad <-
                                           unit.out = unit.in)
                        integ.df <- rbind(integ.df,
                                          data.frame(x = midpoint(wb),
-                                                    xmin = min(wb),
-                                                    xmax = max(wb),
-                                                    yeff = yeff.tmp,
-                                                    yint = yint.tmp,
-                                                    ymax = max(data$y),
-                                                    ymin = min(data$y),
-                                                    ymean = ymean.tmp,
+                                                    wb.xmin = min(wb),
+                                                    wb.xmax = max(wb),
+                                                    wb.yeff = yeff.tmp,
+                                                    wb.yint = yint.tmp,
+                                                    wb.ymax = max(data[["y"]]),
+                                                    wb.ymin = min(data[["y"]]),
+                                                    wb.ymean = ymean.tmp,
                                                     wb.color = color_of(wb),
-                                                    wb.name = labels(wb)$label,
+                                                    wb.name = labels(wb)[["label"]],
                                                     BW.color = black_or_white(color_of(wb)))
                                          )
                      }
                      if (!is.null(xpos.fixed)) {
-                       integ.df$x <- xpos.fixed
+                       integ.df[["x"]] <- xpos.fixed
                      }
                      if (is.null(ypos.fixed)) {
-                       integ.df$y <- with(integ.df, ymin + (ymean - ymin) * ypos.mult)
+                       integ.df[["y"]] <- with(integ.df, wb.ymin + (wb.ymean - wb.ymin) * ypos.mult)
                      } else {
-                       integ.df$y <- ypos.fixed
+                       integ.df[["y"]] <- ypos.fixed
                      }
-                     integ.df$y.label <- sprintf(label.fmt, integ.df$yeff * label.mult)
-                     integ.df$y.label <- sprintf(label.fmt, integ.df$yeff * label.mult)
+                     integ.df[["y.label"]] <- sprintf(label.fmt, integ.df[["wb.yeff"]] * label.mult)
+                     integ.df[["y.label"]] <- sprintf(label.fmt, integ.df[["wb.yeff"]] * label.mult)
                      integ.df
                    },
                    default_aes = ggplot2::aes(label = ..y.label..,
-                                              xmin = ..xmin..,
-                                              xmax = ..xmax..,
+                                              xmin = ..wb.xmin..,
+                                              xmax = ..wb.xmax..,
                                               ymin = 0,
-                                              ymax = ..ymean..,
-                                              yintercept = ..ymean..,
+                                              ymax = ..wb.ymean..,
+                                              yintercept = ..wb.ymean..,
                                               fill = ..wb.color..,
                                               color = ..BW.color..),
                    required_aes = c("x", "y")
